==========
Watermarks
==========

In some cases, a watermark (saying Preliminary) is added to the summarypages,

.. image:: ./examples/watermark.png

This indicates that the pages should be considered Preliminary as the results
cannot be replicated using information extracted from the summarypages.
To remove this watermark, a valid configuration file for
the run (giving settings used for the analysis) and a PSD must be provided to
the `summarypages <../../core/cli/summarypages.html>`_ executable.
